package com.hcloud.microservice.traced.components;

import com.hcloud.microserver.commoncore.base.ResultVO;
import com.hcloud.microserver.commoncore.base.Token;
import com.hcloud.microserver.commoncore.constant.GlobleConstant;
import com.hcloud.microserver.commoncore.util.*;
import com.hcloud.microserver.commoncore.util.string.StringUtils;
import com.hcloud.microservice.goods.facade.clients.GoodsTracedUserManagerService;
import com.hcloud.microservice.goods.facade.entity.GoodsTracedUser;
import com.hcloud.microservice.goods.facade.forms.GoodsTracedUserForm;
import com.hcloud.microservice.traced.common.BaseInfoDO;
import io.swagger.annotations.Api;
import lombok.extern.slf4j.Slf4j;
import me.chanjar.weixin.mp.bean.result.WxMpUser;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.redis.core.RedisTemplate;
import org.springframework.data.redis.core.ValueOperations;
import org.springframework.stereotype.Component;

import java.util.Date;
import java.util.HashMap;
import java.util.LinkedHashMap;
import java.util.Map;
import java.util.concurrent.TimeUnit;

/**
 * @author xiezt
 */
@Slf4j
@Component("wechatManager")
public class WechatManagerComponent {

    private static final String WECHAT_USER_INFO="wechatUserInfo";

    @Autowired
    private RedisTemplate redisTemplate;

    @Autowired
    private GoodsTracedUserManagerService goodsTracedUserManagerService;

    public Map getWechatAccessToken(WxMpUser wxMpUser){
        log.info("wxMpUser======================>{}",wxMpUser);
        Map map = new HashMap();
        if(null!=wxMpUser){
        	//公众号只有在被绑定到微信开放平台帐号下后，才会获取UnionID。只要是同一个微信开放平台帐号下的公众号，用户的UnionID是唯一的
        	String id = null;
        	if(StringUtils.isEmpty(wxMpUser.getUnionId())) {
        		id = wxMpUser.getOpenId();
        	}else {
        		id = wxMpUser.getUnionId();
        	}
        	
        	if(getRedisUserCache(id,map)){
                return map;
            }
            productAccessToken(wxMpUser,map);
            return map;
        }
        log.info("没有获取到微信用户基本信息，请联系开发人员");
        return null;
    }

    /**
     * 缓存过期后的处理
     * @param wxMpUser
     * @param resultMap
     */
    private void productAccessToken(WxMpUser wxMpUser, Map resultMap){
    	GoodsTracedUserForm form = new GoodsTracedUserForm();
    	form.setTracedThirdCode(wxMpUser.getUnionId());
    	form.setTracedUserOpenid(wxMpUser.getOpenId());
        ResultVO resultVO = goodsTracedUserManagerService.searchTracedUserByCode(form);
        if(resultVO.getCode()==0){
            Map userMap = (Map) resultVO.getData();
            GoodsTracedUserForm tracedUserForm = JavaBeanUtils.mapToEntity(userMap,GoodsTracedUserForm.class);
            log.info("tracedUserForm======================>{}",tracedUserForm);
            String key = wxMpUser.getUnionId();
        	if(StringUtils.isEmpty(key)) {
        		key = wxMpUser.getOpenId();
        	}
        	log.info("用户key======================>{}",key);
            if(null!=tracedUserForm.getGuid() && !"".equals(tracedUserForm.getGuid())){
                ValueOperations<String, Object> operations = redisTemplate.opsForValue();
                resultMap.put(WECHAT_USER_INFO,tracedUserForm);
                operations.set(key,tracedUserForm,GlobleConstant.TOKEN_EXPIRES_SECOND,TimeUnit.SECONDS);
            }else{
                GoodsTracedUserForm tuser = new GoodsTracedUserForm();
                tuser.setGuid(UUIDUtils.randomUUID());
                tuser.setTracedUserOpenid(wxMpUser.getOpenId());
                tuser.setTracedThirdCode(wxMpUser.getUnionId());
                tuser.setTracedSex(wxMpUser.getSex());
                tuser.setTracedUserImg(wxMpUser.getHeadImgUrl());
                tuser.setTracedUserName(wxMpUser.getNickname());
                tuser.setState(1);
                tuser.setCreateTime(new Date());
                tuser.setModifiedTime(new Date());
                ResultVO innerVO = goodsTracedUserManagerService.saveTracedUser(tuser);
                if(innerVO.getCode()==0){
                    ValueOperations<String, Object> operations = redisTemplate.opsForValue();
                    resultMap.put(WECHAT_USER_INFO,tuser);
                    operations.set(key,tuser,GlobleConstant.TOKEN_EXPIRES_SECOND,TimeUnit.SECONDS);
                }
                log.info("GoodsTracedUserForm======================>{}",tuser);
            }
        }
    }


    /**
     * 缓存未过期的处理
     * @param openid
     * @param resultMap
     * @return
     */
    private boolean getRedisUserCache(String unionId,Map resultMap){
        if(null!=unionId && !"".equals(unionId)){
            Object obj = redisTemplate.opsForValue().get(unionId);
            log.info("obj========================>{}",obj);
            if(obj!=null){
                ValueOperations<String, Object> operations = redisTemplate.opsForValue();
                GoodsTracedUserForm comp = (GoodsTracedUserForm) obj;
                resultMap.put(WECHAT_USER_INFO,comp);
                operations.set(comp.getTracedThirdCode(),comp,GlobleConstant.ACCESS_TOKEN_EXPIRES_SECOND,TimeUnit.SECONDS);
                return Boolean.TRUE;
            }
        }
        return Boolean.FALSE;
    }
}
