package com.hcloud.microservice.traced.wap;

import com.hcloud.microserver.commoncore.annotation.AuthOrgValidate;
import com.hcloud.microserver.commoncore.base.ResponseBase;
import com.hcloud.microserver.commoncore.base.ResultVO;
import com.hcloud.microservice.goods.facade.clients.GoodsBatchManagerService;
import com.hcloud.microservice.goods.facade.clients.GoodsQRCodeManagerService;
import com.hcloud.microservice.goods.facade.forms.GoodsBatchInfoForm;
import com.hcloud.microservice.traced.common.TracedBaseController;
import io.swagger.annotations.*;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

/**
 * @author xiezt
 */
@Slf4j
@RestController
@RequestMapping("/app/code")
@Api(description = "wap端处理溯源码服务",tags = {"wapCodeService"})
public class CodeInfoManageController extends TracedBaseController {

    @Autowired
    private GoodsQRCodeManagerService goodsQRCodeManagerService;

    @Autowired
    private GoodsBatchManagerService goodsBatchManagerService;

    @ApiOperation(value = "扫描溯源二维码",notes = "通过溯源加密码查询溯源码信息")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "qrToken",value = "溯源加密码", dataType = "String",paramType = "query")
    })
    @ApiResponse(code =0,message = "操作成功")
    @AuthOrgValidate
    @GetMapping("/scanCode")
    public ResponseBase scanQRCodeInfo(@RequestParam("qrToken") String qrToken){
        ResultVO resultVO = goodsQRCodeManagerService.searchGoodsQRCodeInfoByTokenStr(qrToken);
        return responseSuccess(resultVO);
    }

    @ApiOperation(value = "保存评价信息",notes = "保存评价信息")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "goodsBatchInfoForm",value = "评价信息", dataType = "GoodsBatchInfoForm")
    })
    @ApiResponse(code =0,message = "保存成功")
    @AuthOrgValidate
    @PostMapping("/saveFeedback")
    public ResponseBase saveFeedbackInfo(@RequestBody GoodsBatchInfoForm goodsBatchInfoForm){
        ResultVO resultVO = goodsBatchManagerService.saveAllFeedbackInfo(goodsBatchInfoForm);
        return responseSuccess(resultVO);
    }

    @ApiOperation(value = "查询评价信息",notes = "查询评价信息")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "userId",value = "用户Id", dataType = "String"),
            @ApiImplicitParam(name = "batchId",value = "商品批次ID", dataType = "String")
    })
    @ApiResponse(code =0,message = "查询成功")
    @AuthOrgValidate
    @GetMapping("/getFeedback")
    public ResponseBase searchFeedbackInfo(@RequestParam("userId") String userId,
                                           @RequestParam("batchId") String batchId){
        ResultVO resultVO = goodsBatchManagerService.searchAllFeedbackInfo(batchId,userId);
        return responseSuccess(resultVO);
    }


    @ApiOperation(value = "查询溯源码信息",notes = "通过溯源码加密字符，查询溯源码信息")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "qrToken",value = "溯源码加密字符",dataType = "String",paramType = "query")
    })
    @ApiResponse(code =0,message = "操作成功")
    @AuthOrgValidate
    @GetMapping("/detail")
    public ResponseBase getQRCodeInfo(@RequestParam("qrToken") String qrToken){
        ResultVO resultVO = goodsQRCodeManagerService.getGoodsQRCodeDetailInfoByToken(qrToken);
        return responseSuccess(resultVO);
    }

}
