package com.hcloud.microservice.traced.wap;

import com.hcloud.microserver.commoncore.annotation.AuthOrgValidate;
import com.hcloud.microserver.commoncore.base.ResponseBase;
import com.hcloud.microserver.commoncore.base.ResultVO;
import com.hcloud.microserver.commoncore.enums.OrgAuthEnum;
import com.hcloud.microservice.goods.facade.clients.GoodsBatchGradeManagerService;
import com.hcloud.microservice.goods.facade.clients.GoodsFeedbackManagerService;
import com.hcloud.microservice.goods.facade.forms.GoodsBatchFeedbackForm;
import com.hcloud.microservice.goods.facade.forms.GoodsBatchGradeForm;
import com.hcloud.microservice.traced.common.TracedBaseController;
import io.swagger.annotations.*;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.Date;

/**
 * @author xiezt
 */
@RestController
@Api(description = "评价服务")
public class GoodsFeedbackManageController extends TracedBaseController {

    private static final Logger LOGGER = LoggerFactory.getLogger(GoodsFeedbackManageController.class);

    @Autowired
    private GoodsFeedbackManagerService goodsFeedbackManagerService;

    @Autowired
    private GoodsBatchGradeManagerService goodsBatchGradeManagerService;


    @ApiOperation(value = "分页查询评价信息",notes = "分页查询商品评价信息，默认分页条数10条")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "goodsBatchFeedbackForm",value = "查询条件",dataType = "GoodsBatchFeedbackForm")
    })
    @ApiResponse(code =0,message = "查询成功")
    @AuthOrgValidate(value = OrgAuthEnum.PLATFORM_ORG_EXTENDS)
    @PostMapping("/web/feedback/searchByPage")
    public ResponseBase searchFeedbackByPage(@RequestBody GoodsBatchFeedbackForm goodsBatchFeedbackForm){
        // 获取用户id
        String orgGuid = this.getOrgGuid();
        LOGGER.info("当前用户机构guid=============>{}", orgGuid);
        goodsBatchFeedbackForm.setFkOrgGuid(orgGuid);
        ResultVO resultVO = goodsFeedbackManagerService.searchGoodsFeedbackByPage(goodsBatchFeedbackForm);
        return responseSuccess(resultVO);
    }

    @ApiOperation(value = "分页查询评级信息",notes = "分页查询商品评级信息，默认分页条数10条")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "gradeForm",value = "查询条件",dataType = "GoodsBatchGradeForm")
    })
    @ApiResponse(code =0,message = "查询成功")
    @AuthOrgValidate(value = OrgAuthEnum.PLATFORM_ORG_EXTENDS)
    @PostMapping("/web/grade/searchByPage")
    public ResponseBase searchBatchGradeByPage(@RequestBody GoodsBatchGradeForm gradeForm){
        ResultVO resultVO = goodsBatchGradeManagerService.searchBatchGradeByPage(gradeForm);
        return responseSuccess(resultVO);
    }

    @ApiOperation(value = "通过溯源用户查询商品评价信息",notes = "通过溯源用户查询商品评价信息")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "userId",value = "用户ID",dataType = "String",paramType = "query"),
            @ApiImplicitParam(name = "batchId",value = "商品批次Id",dataType = "String",paramType = "query"),
            @ApiImplicitParam(name = "fkBatchRecordGuid",value = "溯源码Id",dataType = "String",paramType = "query")
    })
    @ApiResponse(code =0,message = "查询成功")
    @AuthOrgValidate
    @GetMapping("/wap/feedback/searchByUid")
    public ResponseBase searchFeedbackByUid(@RequestParam("userId") String userId,
                                            @RequestParam("batchId") String batchId,
                                            @RequestParam("fkBatchRecordGuid") String fkBatchRecordGuid){
        ResultVO resultVO = goodsFeedbackManagerService.getGoodsFeedbackByUserId(userId,fkBatchRecordGuid);
        return responseSuccess(resultVO);
    }

    @ApiOperation(value = "通过溯源用户查询商品评级信息",notes = "通过溯源用户查询商品评级信息")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "userId",value = "用户ID",dataType = "String",paramType = "query"),
            @ApiImplicitParam(name = "batchId",value = "商品批次Id",dataType = "String",paramType = "query"),
            @ApiImplicitParam(name = "fkBatchRecordGuid",value = "溯源码Id",dataType = "String",paramType = "query")
    })
    @ApiResponse(code =0,message = "查询成功")
    @AuthOrgValidate
    @GetMapping("/wap/grade/searchByUid")
    public ResponseBase searchGradeByUid(@RequestParam("userId") String userId,
                                         @RequestParam("batchId") String batchId,
                                         @RequestParam("fkBatchRecordGuid") String fkBatchRecordGuid){
        ResultVO resultVO = goodsBatchGradeManagerService.getBatchGradeByUserId(userId,fkBatchRecordGuid);
        return responseSuccess(resultVO);
    }


    @ApiOperation(value = "保存商品评价信息",notes = "保存用户评价信息")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "feedbackForm",value = "评价内容",dataType = "GoodsBatchFeedbackForm")
    })
    @ApiResponse(code =0,message = "查询成功")
    @AuthOrgValidate
    @PostMapping("/wap/feedback/save")
    public ResponseBase saveFeedbackInfo(@RequestBody GoodsBatchFeedbackForm feedbackForm){
        feedbackForm.setState(1);
        feedbackForm.setCreateTime(new Date());
        feedbackForm.setModifiedTime(new Date());
        ResultVO resultVO =  goodsFeedbackManagerService.saveGoodsFeedbackInfo(feedbackForm);
        return responseSuccess(resultVO);

    }

    @ApiOperation(value = "保存商品评级信息",notes = "保存用户评级信息")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "gradeForm",value = "评级信息",dataType = "GoodsBatchGradeForm")
    })
    @ApiResponse(code =0,message = "操作成功")
    @AuthOrgValidate
    @PostMapping("/wap/grade/save")
    public ResponseBase saveGradeInfo(@RequestBody GoodsBatchGradeForm gradeForm){
        gradeForm.setState(1);
        gradeForm.setCreateTime(new Date());
        gradeForm.setModifiedTime(new Date());
        ResultVO resultVO = goodsBatchGradeManagerService.saveBatchGradeInfo(gradeForm);
        return responseSuccess(resultVO);
    }


    @ApiOperation(value = "批量删除商品用户评级信息",notes = "批量删除商品用户评级信息")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "gradeForm",value = "查询条件",dataType = "GoodsBatchGradeForm")
    })
    @ApiResponse(code =0,message = "查询成功")
    @AuthOrgValidate(value = OrgAuthEnum.PLATFORM_ORG_EXTENDS)
    @PostMapping("/web/grade/batchDel")
    public ResponseBase delGradeInfo(@RequestBody GoodsBatchGradeForm gradeForm){
        ResultVO resultVO = goodsBatchGradeManagerService.delBatchGradeInfo(gradeForm);
        return responseSuccess(resultVO);
    }

    @ApiOperation(value = "批量删除商品用户评价信息",notes = "批量删除商品用户评价信息")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "feedbackForm",value = "查询条件",dataType = "GoodsBatchFeedbackForm")
    })
    @ApiResponse(code =0,message = "查询成功")
    @AuthOrgValidate(value = OrgAuthEnum.PLATFORM_ORG_EXTENDS)
    @PostMapping("/web/feedback/batchDel")
    public ResponseBase delFeedbackInfo(@RequestBody GoodsBatchFeedbackForm feedbackForm){
        ResultVO resultVO = goodsFeedbackManagerService.delGoodsFeedbackInfo(feedbackForm);
        return responseSuccess(resultVO);
    }
}
