package com.hcloud.microservice.traced.wap;

import com.hcloud.microserver.commoncore.annotation.AuthOrgValidate;
import com.hcloud.microserver.commoncore.base.ResponseBase;
import com.hcloud.microserver.commoncore.base.ResultVO;
import com.hcloud.microserver.commoncore.enums.ResultEnum;
import com.hcloud.microservice.goods.facade.forms.GoodsTracedUserForm;
import com.hcloud.microservice.traced.common.TracedBaseController;
import com.hcloud.microservice.traced.components.WechatManagerComponent;
import com.hcloud.microservice.traced.config.WxMpConfiguration;
import io.swagger.annotations.*;
import lombok.extern.slf4j.Slf4j;
import me.chanjar.weixin.common.bean.WxJsapiSignature;
import me.chanjar.weixin.common.error.WxErrorException;
import me.chanjar.weixin.common.util.http.URIUtil;
import me.chanjar.weixin.mp.api.WxMpService;
import me.chanjar.weixin.mp.bean.result.WxMpOAuth2AccessToken;
import me.chanjar.weixin.mp.bean.result.WxMpUser;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

import java.util.Map;


/**
 * @author xiezt
 */
@Slf4j
@RestController
@RequestMapping("/wap/wechat")
@Api(description = "微信api服务")
public class WechatManagerController extends TracedBaseController {

    private static final String WECHAT_AUTH_SCOPE="snsapi_userinfo";

    private static final String WECHAT_USER_INFO="wechatUserInfo";

    @Value("${wx.mp.appId}")
    private String appid;

    @Value("${wx.auth.redirecturl}")
    private String wechatRedirectUrl;

    private String wechatForwardUrl;

    @Autowired
    private WechatManagerComponent wechatManager;

    @ApiOperation(value = "微信登录",notes = "微信登录")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "furl",value = "回调微信url", dataType = "String",paramType = "query")
    })
    @ApiResponse(code =0,message = "查询成功")
    @GetMapping("/login")
    @AuthOrgValidate
    public void login(@RequestParam("furl") String furl){
        wechatForwardUrl = furl;
        log.info("appid is ================>{}",appid);
        final WxMpService wxMpService = WxMpConfiguration.getMpServices().get(appid);
        String authUrls= wxMpService.oauth2buildAuthorizationUrl(wechatRedirectUrl,WECHAT_AUTH_SCOPE,URIUtil.encodeURIComponent(wechatForwardUrl));
        try {
            log.info("authUrls===============>{}",authUrls);
            this.getResponseObject().sendRedirect(authUrls);
        } catch (Exception e) {
            e.printStackTrace();
            log.error("请求微信权限地址错误请检查配置参数,配置的url:{}",authUrls);
        }
    }


    @ApiOperation(value = "获取用户数据库id",notes = "微信回调接口请勿直接请求")
    @ApiResponse(code =500,message = "请求的配置参数有问题")
    @GetMapping("/doLogin")
    @AuthOrgValidate
    public void doLogin(@RequestParam("code") String code){
        if(null!=code && !"".equals(code)){
            log.info("微信权限认证code是====================>{}",code);
           final WxMpService wxMpService = WxMpConfiguration.getMpServices().get(appid);
            try {
                WxMpOAuth2AccessToken accessToken = wxMpService.oauth2getAccessToken(code);
                if(accessToken!=null ){
                  log.info("accessToken object is:{}",accessToken);
                  WxMpUser wxMpUser = wxMpService.oauth2getUserInfo(accessToken,"");
                  log.info("wxMpUser object is:{}",wxMpUser);
                  Map map = wechatManager.getWechatAccessToken(wxMpUser);
                  if(null!=map && map.size()>0){
                      GoodsTracedUserForm tracedUserForm = (GoodsTracedUserForm) map.get(WECHAT_USER_INFO);
                      log.info("redirectUrl======================>{}",wechatForwardUrl+"?userId="+tracedUserForm.getGuid());
                      this.getResponseObject().sendRedirect(wechatForwardUrl+"?userId="+tracedUserForm.getGuid());
                  }else {
                      this.getResponseObject().sendRedirect(wechatForwardUrl);
                  }
                }
            } catch (Exception e) {
                log.error("微信参数错误，请查看参数配置谢谢");
                e.printStackTrace();
            }
        }
    }
    
    /*微信js签名接口*/
    @ApiOperation(value = "微信js签名接口",notes = "微信js签名接口")
    @GetMapping("/getJsapiTicket")
    @AuthOrgValidate
    public ResponseBase getJsapiTicket(String url) {
    	WxJsapiSignature jsapiSignature = null;
        ResultVO resultVO = new ResultVO();
        try {
        	//WxMpService wxMpService = context.getBean(WxMpService.class);
        	final WxMpService wxMpService = WxMpConfiguration.getMpServices().get(appid);
            jsapiSignature = wxMpService.createJsapiSignature(url);
            resultVO.setCode(ResultEnum.SUCCESS.getCode());
            resultVO.setData(jsapiSignature);
        } catch (WxErrorException e) {
            e.printStackTrace();
            System.err.print(e.getError());
            resultVO.setCode(ResultEnum.FAILURE.getCode());
            resultVO.setData("微信js签名失败");
        }
        return responseSuccess(resultVO);
    }
}
