package com.hcloud.microservice.traced.web.goodsmanager;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONObject;
import com.hcloud.microserver.commoncore.annotation.AuthOrgValidate;
import com.hcloud.microserver.commoncore.annotation.AuthValidate;
import com.hcloud.microserver.commoncore.base.ResponseBase;
import com.hcloud.microserver.commoncore.base.ResultVO;
import com.hcloud.microserver.commoncore.enums.OrgAuthEnum;
import com.hcloud.microserver.commoncore.enums.ResultEnum;
import com.hcloud.microserver.commoncore.util.BeanCopyUtil;
import com.hcloud.microserver.commoncore.util.DateUtils;
import com.hcloud.microserver.commoncore.util.EasyHttpUtils;
import com.hcloud.microservice.goods.facade.clients.GoodsBatchManagerService;
import com.hcloud.microservice.goods.facade.entity.GoodsInterAuxiliary;
import com.hcloud.microservice.goods.facade.forms.GoodsBatchInfoForm;
import com.hcloud.microservice.traced.common.BaseInfoDO;
import com.hcloud.microservice.traced.common.TracedBaseController;
import io.swagger.annotations.*;

import java.util.ArrayList;
import java.util.List;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.util.StringUtils;
import org.springframework.web.bind.annotation.*;

/**
 * @author xiezt
 */
@RestController
@RequestMapping("/web/goods/batch")
@Api(description = "商品批次服务")
public class GoodsBatchManageController extends TracedBaseController {

    public static final Integer ONEC_MAX_QR_COUNT=10000;

    @Autowired
    private GoodsBatchManagerService goodsBatchManagerService;
    
    @Value("${wlw.address}")
    private String wlwhost;

    @ApiOperation(value = "查询商品批次记录信息",notes = "分页查询商品批次记录信息，默认分页条数10条")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "goodsBatchInfoForm",value = "查询条件",dataType = "GoodsInfoForm")
    })
    @ApiResponse(code =0,message = "查询成功")
    @AuthOrgValidate(value = OrgAuthEnum.PLATFORM_GOODS_BATCH_QUERY)
    @PostMapping("/searchByPage")
    public ResponseBase searchByPage(@RequestBody GoodsBatchInfoForm goodsBatchInfoForm){
        BaseInfoDO infoDO = this.initiSaveObject();
        if(infoDO==null){return responseError(new ResultVO(ResultEnum.TOKEN_EXPIRED));}
        BeanCopyUtil.copyBean(infoDO,goodsBatchInfoForm);
        ResultVO resultVO = goodsBatchManagerService.queryGoodsBatchRecordByPage(goodsBatchInfoForm);
        return responseSuccess(resultVO);
    }

    @ApiOperation(value = "添加商品批次记录信息",notes = "通过商品批次基本信息，添加商品批次记录")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "goodsBatchInfoForm",value = "商品批次基本信息",dataType = "GoodsBatchInfoForm")
    })
    @ApiResponse(code =0,message = "操作成功")
    @AuthOrgValidate(value = OrgAuthEnum.PLATFORM_GOODS_BATCH_ADD)
    @PostMapping("/add")
    public ResponseBase addGoodsBatchInfo(@RequestBody GoodsBatchInfoForm goodsBatchInfoForm){
        BaseInfoDO baseInfoDO = this.initiSaveObject();
        if(baseInfoDO==null){
           return responseError(new ResultVO(ResultEnum.TOKEN_EXPIRED));
        }
        BeanCopyUtil.copyBean(baseInfoDO,goodsBatchInfoForm);
        goodsBatchInfoForm.setGoodsProductDate(DateUtils.str2Date(goodsBatchInfoForm.getProductDateStr()));
        ResultVO resultVO = goodsBatchManagerService.addGoodsBatchRecord(goodsBatchInfoForm);
        return responseSuccess(resultVO);
    }

    @ApiOperation(value = "修改商品批次记录信息",notes = "通过商品批次基本信息，修改商品批次记录")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "goodsBatchInfoForm",value = "商品批次基本信息",dataType = "GoodsBatchInfoForm")
    })
    @ApiResponse(code =0,message = "操作成功")
    @AuthOrgValidate(value = OrgAuthEnum.PLATFORM_GOODS_BATCH_EDIT)
    @PostMapping("/edit")
    public ResponseBase editGoodsBatchInfo(@RequestBody GoodsBatchInfoForm goodsBatchInfoForm){
        BaseInfoDO baseInfoDO = this.initiSaveObject();
        if(baseInfoDO==null){
            return responseError(new ResultVO(ResultEnum.TOKEN_EXPIRED));
        }
        BeanCopyUtil.copyBean(baseInfoDO,goodsBatchInfoForm);
        goodsBatchInfoForm.setGoodsProductDate(DateUtils.str2Date(goodsBatchInfoForm.getProductDateStr()));
        ResultVO resultVO = goodsBatchManagerService.editGoodsBatchRecord(goodsBatchInfoForm);
        return responseSuccess(resultVO);
    }

    @ApiOperation(value = "删除商品批次记录信息",notes = "通过商品批次唯一标识，删除商品批次记录信息")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "guid",value = "商品批次唯一标识",dataType = "String",paramType = "query")
    })
    @ApiResponse(code =0,message = "操作成功")
    @AuthOrgValidate(value = OrgAuthEnum.PLATFORM_GOODS_BATCH_DEL)
    @GetMapping("/del")
    public ResponseBase delGoodsBatchInfo(@RequestParam("guid") String guid){
        if(this.getOrgGuid()==null || "".equals(this.getOrgGuid())) {
            return responseError(new ResultVO(ResultEnum.TOKEN_EXPIRED));
        }
        ResultVO resultVO = goodsBatchManagerService.delGoodsBatchRecordById(guid,this.getOrgGuid());
        return responseSuccess(resultVO);
    }

    @ApiOperation(value = "查询商品批次明细信息",notes = "通过商品批次唯一标识，查询商品批次明细信息")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "guid",value = "商品批次唯一标识",dataType = "String",paramType = "query")
    })
    @ApiResponse(code =0,message = "操作成功")
    @AuthOrgValidate(value = OrgAuthEnum.PLATFORM_GOODS_BATCH_GET)
    @GetMapping("/searchById")
    public ResponseBase searchBatchInfoById(@RequestParam("guid") String guid){
        ResultVO resultVO = goodsBatchManagerService.getGoodsBatchRecordById(guid);
        return responseSuccess(resultVO);
    }


    @ApiOperation(value = "生成溯源码记录",notes = "通过商品批次唯一标识，查询商品批次明细信息")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "goodsBatchInfoForm",value = "商品批次信息",dataType = "GoodsBatchInfoForm")
    })
    @ApiResponse(code =0,message = "操作成功")
    @AuthOrgValidate(value = OrgAuthEnum.PLATFORM_GOODS_BATCH_CODE)
    @PostMapping("/batchGoodsQRCode")
    public ResponseBase saveQRCodeInfo(@RequestBody GoodsBatchInfoForm goodsBatchInfoForm){
        BaseInfoDO baseInfoDO = this.initiSaveObject();
        if(baseInfoDO==null){
            return responseError(new ResultVO(ResultEnum.TOKEN_EXPIRED));
        }
        Integer qcount = goodsBatchInfoForm.getQrcodeCount();
        if(qcount==null || qcount<=0 || qcount>=ONEC_MAX_QR_COUNT){
            return responseError(new ResultVO(ResultEnum.PARAMETER_INPUT_ERROR));
        }
        BeanCopyUtil.copyBean(baseInfoDO,goodsBatchInfoForm);
        ResultVO resultVO = goodsBatchManagerService.batchGoodsQRCode(goodsBatchInfoForm);
        return responseSuccess(resultVO);
    }
    
    @ApiOperation(value = "查询产地物联检测信息",notes = "查询产地物联检测信息")
    @ApiImplicitParams({
    	@ApiImplicitParam(name = "fieldGuid",value = "产地id",dataType = "String")
    })
    @ApiResponse(code =0,message = "操作成功")
    @AuthOrgValidate
    @GetMapping("/getInterAuxList")
    public ResponseBase getInterAuxList(@RequestParam("fieldGuid") String fieldGuid,String goodsBatchGuid){
    	ResultVO resultVO = new ResultVO<>();
    	
    	EasyHttpUtils easyHttpUtils = EasyHttpUtils.LoadInstance();
    	String url = wlwhost + "/devid/orchardSeCon?base_id=" + fieldGuid;
    	String s = null;
    	try {
    		s = easyHttpUtils.get(url);
		} catch (Exception e) {
			// TODO: handle exception
			System.out.println(e.getMessage());
		}
    	
    	if(s == null) {
    		resultVO.setCode(1);
        	resultVO.setMsg("物联网系统服务断开");
        	return responseError(resultVO);
    	}
        JSONObject jsonObject = JSON.parseObject(s);
        String key = "retHead";
        JSONObject retDataJson = jsonObject.getJSONObject(key);
        key = "errCod";
        String string = retDataJson.getString(key);
        List<Object> list = null;
        List<GoodsInterAuxiliary> interAuxList = new ArrayList<>();
        if ("0".equals(string)) {
            key = "retBody";
            retDataJson = jsonObject.getJSONObject(key);
            if (!StringUtils.isEmpty(retDataJson)) {
                key = "list";
                list = retDataJson.getJSONArray(key);
                
                if(list != null && list.size() > 0) {
                	for (Object object : list) {
                		JSONObject date = (JSONObject) object;
                		GoodsInterAuxiliary form = new GoodsInterAuxiliary();
                		form.setFkGoodsBatchGuid(goodsBatchGuid);
						form.setAuxItme(date.getString("orchard_type"));
						form.setAuxItmeNormval(date.getString("dat_value") != null ? date.getString("dat_value") : "0");
						//form.setAuxItmeNormval(date.getString("dat_value") != null ? date.getString("dat_value") + date.getString("unit") : "0" + date.getString("unit"));
						form.setUnit(date.getString("unit"));
						interAuxList.add(form);
					}
                }
            }
            
            resultVO.setData(interAuxList);
        }else {
        	resultVO.setCode(1);
        	resultVO.setMsg("物联网系统服务断开");
        }
        
    	return responseSuccess(resultVO);
    }
    
}
