package com.hcloud.microservice.traced.web.goodsmanager;

import java.util.Date;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.repository.query.Param;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import com.hcloud.microserver.commoncore.annotation.AuthOrgValidate;
import com.hcloud.microserver.commoncore.base.ResponseBase;
import com.hcloud.microserver.commoncore.base.ResultVO;
import com.hcloud.microserver.commoncore.enums.OrgAuthEnum;
import com.hcloud.microserver.commoncore.exception.GlobalException;
import com.hcloud.microserver.commoncore.util.BeanCopyUtil;
import com.hcloud.microserver.commoncore.util.string.StringUtil;
import com.hcloud.microservice.goods.facade.clients.GoodsDealerClient;
import com.hcloud.microservice.goods.facade.entity.GoodsDealer;
import com.hcloud.microservice.goods.facade.forms.GoodsDealerForm;
import com.hcloud.microservice.traced.common.BaseInfoDO;
import com.hcloud.microservice.traced.common.TracedBaseController;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiResponse;

/**
 * 经销商管理
 * @author lym
 *
 */
@RestController
@RequestMapping("/web/goods/dealer")
@Api(description = "经销商信息管理")
public class GoodsDealerManageController extends TracedBaseController{
	
	@Autowired
	private GoodsDealerClient goodsDealerClient;
	
	@ApiOperation(value = "获取经销商编码",notes = "获取经销商编码")
	@ApiResponse(code =0,message = "操作成功")
	@AuthOrgValidate
	@GetMapping("/getCode")
	public ResponseBase getMaxCode() {
		ResultVO resultVO = goodsDealerClient.getMaxCode();
		return responseSuccess(resultVO);
	}
	
	@ApiOperation(value = "添加经销商信息",notes = "添加经销商信息")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "goodsDealer",value = "经销商信息",dataType = "GoodsDealer")
    })
    @ApiResponse(code =0,message = "操作成功")
    @AuthOrgValidate(value = OrgAuthEnum.PLATFORM_SYS_DEALER_ADD)
	@PostMapping("/add")
	public ResponseBase add(@RequestBody GoodsDealer goodsDealer) {
		goodsDealer.setFkOrgGuid(this.getOrgGuid());
		goodsDealer.setCreateUser(this.getUserId());
		goodsDealer.setCreateTime(new Date());
		goodsDealer.setState(1);
		ResultVO resultVO = goodsDealerClient.add(goodsDealer);
		return responseSuccess(resultVO);
	}
	
	@ApiOperation(value = "查询经销商信息",notes = "查询经销商信息")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "guid",value = "主键",dataType = "String")
    })
    @ApiResponse(code =0,message = "操作成功")
    @AuthOrgValidate(value = OrgAuthEnum.PLATFORM_SYS_DEALER)
	@GetMapping("/findById")
	public ResponseBase findById(@Param("guid") String guid) {
		ResultVO resultVO = goodsDealerClient.findById(guid);
		return responseSuccess(resultVO);
	}
	
	@ApiOperation(value = "修改经销商信息",notes = "修改经销商信息")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "goodsDealer",value = "经销商信息",dataType = "GoodsDealer")
    })
    @ApiResponse(code =0,message = "操作成功")
    @AuthOrgValidate(value = OrgAuthEnum.PLATFORM_SYS_DEALER_EDIT)
	@PostMapping("/edit")
	public ResponseBase edit(@RequestBody GoodsDealer goodsDealer) {
		goodsDealer.setModifiedUser(this.getUserId());
		goodsDealer.setModifiedTime(new Date());
		ResultVO resultVO = goodsDealerClient.edit(goodsDealer);
		return responseSuccess(resultVO);
	}
 
	@ApiOperation(value = "查询经销商信息",notes = "分页查询经销商信息，默认分页条数10条")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "goodsDealerForm",value = "查询条件",dataType = "GoodsDealerForm")
    })
    @ApiResponse(code =0,message = "查询成功")
    @AuthOrgValidate(value = OrgAuthEnum.PLATFORM_SYS_DEALER)
	@PostMapping("/searchByPage")
    public ResponseBase searchByPage(@RequestBody GoodsDealerForm goodsDealerForm){
		goodsDealerForm.setFkOrgGuid(this.getOrgGuid());
        ResultVO resultVO = goodsDealerClient.searchByPage(goodsDealerForm);
        return responseSuccess(resultVO);
    }
	
	@ApiOperation(value = "删除经销商信息",notes = "删除经销商信息")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "guid",value = "主键",dataType = "String")
    })
    @ApiResponse(code =0,message = "操作成功")
    @AuthOrgValidate(value = OrgAuthEnum.PLATFORM_SYS_DEALER)
	@GetMapping("/delete")
	public ResponseBase delete(@Param("guid") String guid) {
		ResultVO resultVO = goodsDealerClient.delete(guid);
		return responseSuccess(resultVO);
	}
	
	@ApiOperation(value = "查询经销商信息",notes = "查询经销商信息")
	@ApiImplicitParams({
		@ApiImplicitParam(name = "goodsDealerForm",value = "查询条件",dataType = "GoodsDealerForm")
	})
	@ApiResponse(code =0,message = "操作成功")
	@AuthOrgValidate
	@PostMapping("/selectGoodsDealer")
	public ResponseBase delete(@RequestBody GoodsDealerForm goodsDealerForm) {
		if(StringUtil.isEmpty(goodsDealerForm.getFkOrgGuid())) {
			throw new GlobalException(1, "获取附近经销商信息失败");
		}
		/*if(StringUtil.isEmpty(goodsDealerForm.getLatitudeLongitude())) {
			throw new GlobalException(1, "获取定位失败，请检查是否打开定位");
		}*/
		
		ResultVO resultVO = goodsDealerClient.searchByPage(goodsDealerForm);
		return responseSuccess(resultVO);
	}
}
