package com.hcloud.microservice.traced.web.goodsmanager;

import java.util.ArrayList;
import java.util.Date;
import java.util.List;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.util.StringUtils;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONObject;
import com.hcloud.microserver.commoncore.annotation.AuthOrgValidate;
import com.hcloud.microserver.commoncore.base.ResponseBase;
import com.hcloud.microserver.commoncore.base.ResultVO;
import com.hcloud.microserver.commoncore.constant.GlobleConstant;
import com.hcloud.microserver.commoncore.enums.OrgAuthEnum;
import com.hcloud.microserver.commoncore.enums.ResultEnum;
import com.hcloud.microserver.commoncore.util.BeanCopyUtil;
import com.hcloud.microserver.commoncore.util.EasyHttpUtils;
import com.hcloud.microservice.goods.facade.clients.GoodsFieldManageService;
import com.hcloud.microservice.goods.facade.forms.GoodsFieldForm;
import com.hcloud.microservice.org.facade.client.PositionManagerService;
import com.hcloud.microservice.traced.common.BaseInfoDO;
import com.hcloud.microservice.traced.common.TracedBaseController;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiResponse;

/**
 * @author xiezt
 */
@RestController
@RequestMapping("/web/goods/field")
@Api(description = "商品产地服务")
public class GoodsFieldManageController extends TracedBaseController {

    @Autowired
    private GoodsFieldManageService goodsFieldManageService;

    @Autowired
    private PositionManagerService positionManagerService;
    
    @Value("${wlw.address}")
    private String wlwhost;

    @ApiOperation(value = "查询商品产地信息",notes = "分页查询商品产地信息，默认分页条数10条")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "fieldForm",value = "查询条件",dataType = "GoodsFieldForm")
    })
    @ApiResponse(code =0,message = "查询成功")
    @AuthOrgValidate(value = OrgAuthEnum.PLATFORM_GOODS_FIELD_QUERY)
    @PostMapping("/searchByPage")
    public ResponseBase searchByPage(@RequestBody GoodsFieldForm fieldForm){
        BaseInfoDO infoDO = initiSaveObject();
        if(infoDO==null){return responseError(new ResultVO(ResultEnum.TOKEN_EXPIRED));}
        BeanCopyUtil.copyBean(infoDO,fieldForm);
        ResultVO resultVO = goodsFieldManageService.queryGoodsFieldByPage(fieldForm);
        return responseSuccess(resultVO);
    }


    @ApiOperation(value = "添加产地信息",notes = "通过产地属性及附加属性添加产地信息")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "fieldForm",value = "产地信息内容",dataType = "GoodsFieldForm"),
            @ApiImplicitParam(name = "auxList",value = "附加信息列表",dataType = "List")
    })
    @ApiResponse(code =0,message = "操作成功")
    @AuthOrgValidate(value = OrgAuthEnum.PLATFORM_GOODS_FIELD_ADD)
    @PostMapping("/add")
    public ResponseBase addGoodsFieldInfo(@RequestBody GoodsFieldForm fieldForm){
        fieldForm.setFkOrgGuid(this.getOrgGuid());
        fieldForm.setFkProductGuid(GlobleConstant.PRODUCT_GUID);
        fieldForm.setState(1);
        fieldForm.setCreateUser(this.getUserId());
        fieldForm.setModifiedUser(this.getUserId());
        fieldForm.setCreateTime(new Date());
        fieldForm.setModifiedTime(new Date());
        ResultVO resultVO = goodsFieldManageService.addGoodsField(fieldForm);
        return responseSuccess(resultVO);
    }

    @ApiOperation(value = "修改产地信息",notes = "通过产地属性及附加属性修改产地信息")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "fieldForm",value = "产地信息内容",dataType = "GoodsFieldForm"),
            @ApiImplicitParam(name = "auxList",value = "附加信息列表",dataType = "List")
    })
    @ApiResponse(code =0,message = "操作成功")
    @AuthOrgValidate(value = OrgAuthEnum.PLATFORM_GOODS_FIELD_EDIT)
    @PostMapping("/edit")
    public ResponseBase editGoodsFieldInfo(@RequestBody GoodsFieldForm fieldForm){
    	fieldForm.setFkOrgGuid(this.getOrgGuid());
    	fieldForm.setModifiedUser(this.getUserId());
        fieldForm.setModifiedTime(new Date());
        ResultVO resultVO = goodsFieldManageService.editGoodsField(fieldForm);
        return responseSuccess(resultVO);
    }

    @ApiOperation(value = "查询产地明细信息",notes = "通过产地唯一标识查询产地信息")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "guid",value = "产地唯一标识",dataType = "String",paramType = "query")
    })
    @ApiResponse(code =0,message = "操作成功")
    @AuthOrgValidate(value = OrgAuthEnum.PLATFORM_GOODS_FIELD_GET)
    @GetMapping("/searchById")
    public ResponseBase getGoodsFieldInfo(@RequestParam("guid") String guid){
        ResultVO resultVO = goodsFieldManageService.getGoodsField(guid,this.getOrgGuid());
        return responseSuccess(resultVO);
    }


    @ApiOperation(value = "删除产地信息",notes = "通过产品唯一主键逻辑删除产地信息")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "guid",value = "产地唯一标识",dataType = "String",paramType = "query")
    })
    @ApiResponse(code =0,message = "操作成功")
    @AuthOrgValidate(value = OrgAuthEnum.PLATFORM_GOODS_FIELD_DEL)
    @GetMapping("/del")
    public ResponseBase delGoodsFieldInfo(@RequestParam("guid") String guid){
        ResultVO resultVO = goodsFieldManageService.delGoodsField(guid,this.getOrgGuid());
        return responseSuccess(resultVO);
    }


    @ApiOperation(value = "商品地址信息",notes = "商品地址信息")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "parentId",value = "地址编码",dataType = "String",paramType = "query")
    })
    @ApiResponse(code =0,message = "操作成功")
    @AuthOrgValidate
    @GetMapping("/getAreaInfo")
    public ResponseBase getAreaInfoByCode(String parentId){
        if(parentId==null || "".equals(parentId)){
            parentId="#";
        }
        ResultVO resultVO = positionManagerService.getBasePositionByParentCode(parentId);
        return responseSuccess(resultVO);
    }
    
    @ApiOperation(value = "查询物联网基地信息",notes = "查询物联网基地信息")
    @ApiImplicitParams({
    	@ApiImplicitParam(name = "customerId",value = "企业id",dataType = "String")
    })
    @ApiResponse(code =0,message = "操作成功")
    @AuthOrgValidate
    @GetMapping("/getBaseList")
    public ResponseBase getBaseList(String customerId){
    	ResultVO resultVO = new ResultVO<>();
    	List<GoodsFieldForm> GoodsFieldList = new ArrayList<>();
    	
    	EasyHttpUtils easyHttpUtils = EasyHttpUtils.LoadInstance();
    	String url = wlwhost + "/devid/orchardSe?customer_id=" + customerId;
    	String s = null;
    	try {
    		s = easyHttpUtils.get(url);
		} catch (Exception e) {
			// TODO: handle exception
			System.out.println(e.getMessage());
		}
    	
    	if(s == null) {
    		//resultVO.setCode(1);
        	//resultVO.setMsg("物联网系统服务断开");
        	resultVO.setData(GoodsFieldList);
        	return responseError(resultVO);
    	}
        JSONObject jsonObject = JSON.parseObject(s);
        String key = "retHead";
        JSONObject retDataJson = jsonObject.getJSONObject(key);
        key = "errCod";
        String string = retDataJson.getString(key);
        List<Object> list = null;
        
        
        if ("0".equals(string)) {
            key = "retBody";
            retDataJson = jsonObject.getJSONObject(key);
            if (!StringUtils.isEmpty(retDataJson)) {
                key = "list";
                list = retDataJson.getJSONArray(key);
                
                if(list != null && list.size() > 0) {
                	for (Object object : list) {
                		JSONObject date = (JSONObject) object;
						GoodsFieldForm form = new GoodsFieldForm();
						form.setGuid(date.getString("id"));
						form.setFieldName(date.getString("baseName"));
						form.setSaleGoodsRange(date.getString("baseOutput"));
						form.setFieldArea(date.getString("baseScale"));
						form.setProvinceId(date.getString("provinceId"));
						form.setCityId(date.getString("cityId"));
						form.setCountyId(date.getString("areaId"));
						if(date.getString("areaId") != null) {
							form.setFkPostionId(date.getString("areaId"));
						}else if(date.getString("cityId") != null) {
							form.setFkPostionId(date.getString("cityId"));
						}else if(date.getString("provinceId") != null) {
	                		form.setFkPostionId(date.getString("provinceId"));
	                	}
						form.setFieldAddress(date.getString("address"));
						form.setRemark(date.getString("baseSynopsis"));
						GoodsFieldList.add(form);
					}
                }
            }
        }
        
    	resultVO.setData(GoodsFieldList);
    	return responseSuccess(resultVO);
    }

}
