package com.hcloud.microservice.traced.web.goodsmanager;

import com.hcloud.microserver.commoncore.annotation.AuthOrgValidate;
import com.hcloud.microserver.commoncore.annotation.AuthValidate;
import com.hcloud.microserver.commoncore.base.BaseController;
import com.hcloud.microserver.commoncore.base.ResponseBase;
import com.hcloud.microserver.commoncore.base.ResultVO;
import com.hcloud.microserver.commoncore.constant.GlobleConstant;
import com.hcloud.microserver.commoncore.enums.OrgAuthEnum;
import com.hcloud.microserver.commoncore.util.BeanCopyUtil;
import com.hcloud.microservice.goods.facade.clients.GoodsManagerService;
import com.hcloud.microservice.goods.facade.forms.GoodsInfoForm;
import com.hcloud.microservice.traced.common.BaseInfoDO;
import com.hcloud.microservice.traced.common.TracedBaseController;
import io.swagger.annotations.*;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.Date;

/**
 * @author xiezt
 */
@Slf4j
@RestController
@RequestMapping("/web/goods")
@Api(description = "商品服务")
public class GoodsManageController extends TracedBaseController {

    @Autowired
    private GoodsManagerService goodsManagerService;

    @ApiOperation(value = "查询商品信息",notes = "分页查询商品信息，默认分页条数10条")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "goodsInfoForm",value = "查询条件",dataType = "GoodsIForm")
    })
    @ApiResponse(code =0,message = "查询成功")
    @AuthOrgValidate(value = OrgAuthEnum.PLATFORM_GOODS_INFO_QUERY)
    @PostMapping("/searchByPage")
    public ResponseBase searchByPage(@RequestBody GoodsInfoForm goodsInfoForm){
        goodsInfoForm.setFkOrgGuid(this.getOrgGuid());
        ResultVO resultVO = goodsManagerService.searchGoodsInfoByPage(goodsInfoForm);
        return responseSuccess(resultVO);
    }

    @ApiOperation(value = "添加商品信息",notes = "通过商品基本信息，添加商品记录")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "goodsInfoForm",value = "商品基本信息",dataType = "GoodsInfoForm")
    })
    @ApiResponse(code =0,message = "操作成功")
    @AuthOrgValidate(value = OrgAuthEnum.PLATFORM_GOODS_INFO_ADD)
    @PostMapping("/add")
    public ResponseBase addGoodsInfo(@RequestBody GoodsInfoForm goodsInfoForm){
        BaseInfoDO infoDO = this.initiSaveObject();
        BeanCopyUtil.copyBean(infoDO,goodsInfoForm);
        log.info("goodsInfoForm==============>{}",goodsInfoForm);
        ResultVO resultVO = goodsManagerService.addGoodsInfo(goodsInfoForm);
        return responseSuccess(resultVO);
    }

    @ApiOperation(value = "修改商品信息",notes = "通过商品基本信息，修改商品记录")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "goodsInfoForm",value = "修改基本信息",dataType = "GoodsInfoForm")
    })
    @ApiResponse(code =0,message = "操作成功")
    @AuthOrgValidate(value = OrgAuthEnum.PLATFORM_GOODS_INFO_EDIT)
    @PostMapping("/edit")
    public ResponseBase editGoodsInfo(@RequestBody GoodsInfoForm goodsInfoForm){
        ResultVO resultVO = goodsManagerService.editGoodsInfo(goodsInfoForm);
        return responseSuccess(resultVO);
    }


    @ApiOperation(value = "查询商品明细信息",notes = "通过商品唯一标识查询商品记录")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "guid",value = "商品唯一标识",dataType = "String",paramType = "query")
    })
    @ApiResponse(code =0,message = "操作成功")
    @AuthOrgValidate(value = OrgAuthEnum.PLATFORM_GOODS_INFO_GET)
    @GetMapping("/searchById")
    public ResponseBase getGoodsInfo(@RequestParam("guid") String guid){
        ResultVO resultVO = goodsManagerService.getGoodsInfoById(guid);
        return responseSuccess(resultVO);
    }


    @ApiOperation(value = "删除商品信息",notes = "通过商品唯一标识删除商品记录")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "guid",value = "商品唯一标识",dataType = "String",paramType = "query")
    })
    @ApiResponse(code =0,message = "操作成功")
    @AuthOrgValidate(value = OrgAuthEnum.PLATFORM_GOODS_INFO_DEL)
    @GetMapping("/del")
    public ResponseBase delGoodsInfo(@RequestParam("guid") String guid){
        ResultVO resultVO = goodsManagerService.delGoodsInfoById(guid);
        return responseSuccess(resultVO);
    }

}
