package com.hcloud.microservice.traced.web.goodsmanager;

import com.hcloud.microserver.commoncore.annotation.AuthOrgValidate;
import com.hcloud.microserver.commoncore.base.ResponseBase;
import com.hcloud.microserver.commoncore.base.ResultVO;
import com.hcloud.microserver.commoncore.enums.ResultEnum;
import com.hcloud.microserver.commoncore.util.BeanCopyUtil;
import com.hcloud.microservice.goods.facade.clients.GoodsProInputsManagerService;
import com.hcloud.microservice.goods.facade.forms.GoodsProInputsForm;
import com.hcloud.microservice.traced.common.BaseInfoDO;
import com.hcloud.microservice.traced.common.TracedBaseController;
import io.swagger.annotations.*;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

/**
 * @author JYJ
 */
@RestController
@RequestMapping("/web/inputs")
@Api(description = "原料投入品服务")
public class GoodsProInputsManagerController extends TracedBaseController {

    @Autowired
    private GoodsProInputsManagerService goodsProInputsManagerService;

    @ApiOperation(value = "分页查询评价信息",notes = "分页查询商品评价信息，默认分页条数10条")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "goodsBatchFeedbackForm",value = "查询条件",dataType = "GoodsBatchFeedbackForm")
    })
    @ApiResponse(code =0,message = "查询成功")
    @AuthOrgValidate
    @PostMapping("/searchByPage")
    public ResponseBase searchProInputsByPage(@RequestBody GoodsProInputsForm goodsProInputsForm){
       ResultVO resultVO =  goodsProInputsManagerService.searchProInputsByPage(goodsProInputsForm);
        return responseError(resultVO);
    }

    @ApiOperation(value = "查询溯源投入品通批次编号",notes = "查询溯源投入品通批次编号")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "foreignKey",value = "查询条件",dataType = "String",paramType = "query")
    })
    @ApiResponse(code =0,message = "查询成功")
    @AuthOrgValidate
    @GetMapping("/searchByFK")
    public ResponseBase searchProInputsByFK(@RequestParam("foreignKey") String foreignKey){
        ResultVO resultVO =  goodsProInputsManagerService.searchProInputsByFK(foreignKey);
        return responseError(resultVO);
    }

    @ApiOperation(value = "删除生产原料信息",notes = "删除生产原料信息")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "guid",value = "生产原料唯一标识",dataType = "String",paramType = "query")
    })
    @ApiResponse(code =0,message = "查询成功")
    @AuthOrgValidate
    @GetMapping("/del")
    public ResponseBase delProInputs(@RequestParam("guid") String guid){
        ResultVO resultVO =  goodsProInputsManagerService.delProInputs(guid);
        return responseError(resultVO);
    }

    @ApiOperation(value = "保存生产原料信息",notes = "保存生产原料信息")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "goodsProInputsForm",value = "保存生产原料信息",dataType = "GoodsProInputsForm")
    })
    @ApiResponse(code =0,message = "保存成功")
    @AuthOrgValidate
    @PostMapping("/save")
    public ResponseBase saveProInputs(@RequestBody GoodsProInputsForm goodsProInputsForm){
        BaseInfoDO baseInfoDO = this.initiSaveObject();
        if (baseInfoDO==null){return responseError(new ResultVO(ResultEnum.TOKEN_EXPIRED));}
        BeanCopyUtil.copyBean(baseInfoDO,goodsProInputsForm);
        ResultVO resultVO =  goodsProInputsManagerService.saveProInputs(goodsProInputsForm);
        return responseSuccess(resultVO);
    }
}
