package com.hcloud.microservice.traced.web.goodsmanager;

import com.hcloud.microserver.commoncore.annotation.AuthOrgValidate;
import com.hcloud.microserver.commoncore.base.ResponseBase;
import com.hcloud.microserver.commoncore.base.ResultVO;
import com.hcloud.microserver.commoncore.enums.ResultEnum;
import com.hcloud.microserver.commoncore.util.BeanCopyUtil;
import com.hcloud.microservice.goods.facade.clients.GoodsProNormalManagerService;
import com.hcloud.microservice.goods.facade.forms.GoodsProInputsForm;
import com.hcloud.microservice.goods.facade.forms.GoodsProNormalForm;
import com.hcloud.microservice.traced.common.BaseInfoDO;
import com.hcloud.microservice.traced.common.TracedBaseController;
import io.swagger.annotations.*;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

/**
 * @author JYJ
 */
@RestController
@RequestMapping("/web/normal")
@Api(description = "通用生产过程服务")
public class GoodsProNormalManagerController extends TracedBaseController {

    @Autowired
    private GoodsProNormalManagerService goodsProNormalManagerService;

    @ApiOperation(value = "分页查询溯源流通信息",notes = "分页查询溯源流通信息")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "goodsProNormalForm",value = "查询条件",dataType = "GoodsProNormalForm")
    })
    @ApiResponse(code =0,message = "查询成功")
    @AuthOrgValidate
    @PostMapping("/searchByPage")
    public ResponseBase searchProInputsByPage(@RequestBody GoodsProNormalForm goodsProNormalForm){
        ResultVO resultVO =  goodsProNormalManagerService.searchProNormalByPage(goodsProNormalForm);
        return responseSuccess(resultVO);
    }

    @ApiOperation(value = "保存溯源流通信息",notes = "保存溯源流通信息")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "goodsProNormalForm",value = "溯源流通信息",dataType = "GoodsProNormalForm")
    })
    @ApiResponse(code =0,message = "保存成功")
    @AuthOrgValidate
    @PostMapping("/save")
    public ResponseBase saveProNormal(@RequestBody GoodsProNormalForm goodsProNormalForm){
        BaseInfoDO baseInfoDO = this.initiSaveObject();
        if (baseInfoDO==null){return responseError(new ResultVO(ResultEnum.TOKEN_EXPIRED));}
        BeanCopyUtil.copyBean(baseInfoDO,goodsProNormalForm);
        ResultVO resultVO =  goodsProNormalManagerService.saveProNormal(goodsProNormalForm);
        return responseSuccess(resultVO);
    }

    @ApiOperation(value = "更新溯源流通信息",notes = "更新溯源流通信息")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "goodsProNormalForm",value = "查询条件",dataType = "GoodsProNormalForm")
    })
    @ApiResponse(code =0,message = "查询成功")
    @AuthOrgValidate
    @PostMapping("/edit")
    public ResponseBase updateProNormalInfo(@RequestBody GoodsProNormalForm goodsProNormalForm){
        BaseInfoDO baseInfoDO = this.initiSaveObject();
        if (baseInfoDO==null){return responseError(new ResultVO(ResultEnum.TOKEN_EXPIRED));}
        BeanCopyUtil.copyBean(baseInfoDO,goodsProNormalForm);
        ResultVO resultVO =  goodsProNormalManagerService.updateProNormal(goodsProNormalForm);
        return responseSuccess(resultVO);
    }

    @ApiOperation(value = "删除溯源流通信息",notes = "删除溯源流通信息")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "guid",value = "查询条件",dataType = "String",paramType = "query")
    })
    @ApiResponse(code =0,message = "查询成功")
    @AuthOrgValidate
    @GetMapping("/del")
    public ResponseBase delProNormalInfo(@RequestParam("guid") String guid){
        ResultVO resultVO =  goodsProNormalManagerService.delProNormalByPK(guid);
        return responseSuccess(resultVO);
    }
}
