package com.hcloud.microservice.traced.web.goodsmanager;

import com.hcloud.microserver.commoncore.annotation.AuthOrgValidate;
import com.hcloud.microserver.commoncore.base.ResponseBase;
import com.hcloud.microserver.commoncore.base.ResultVO;
import com.hcloud.microserver.commoncore.enums.OrgAuthEnum;
import com.hcloud.microserver.commoncore.enums.ResultEnum;
import com.hcloud.microserver.commoncore.exception.GlobalException;
import com.hcloud.microserver.commoncore.util.BeanCopyUtil;
import com.hcloud.microservice.goods.facade.clients.GoodsQRCodeManagerService;
import com.hcloud.microservice.goods.facade.forms.GoodsQRCodeInfoForm;
import com.hcloud.microservice.traced.common.BaseInfoDO;
import com.hcloud.microservice.traced.common.TracedBaseController;
import io.swagger.annotations.*;
import lombok.extern.slf4j.Slf4j;

import java.util.List;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.bind.annotation.RestController;

/**
 * @author xiezt
 */
@Slf4j
@RestController
@RequestMapping("/web/code/info")
@Api(description = "web端处理溯源码服务",tags = {"webCodeService"})
public class QRCodeInfoManageController extends TracedBaseController {

    @Autowired
    private GoodsQRCodeManagerService goodsQRCodeManagerService;

    @ApiOperation(value = "废弃溯源",notes = "通过溯源码唯一标识属性，废弃溯源码信息")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "guid",value = "溯源码唯一标识",dataType = "String",paramType = "query")
    })
    @ApiResponse(code =0,message = "操作成功")
    @AuthOrgValidate
    @GetMapping("/forbidden")
    public ResponseBase forbiddenQRCodeInfo(@RequestParam("guid") String guid){
        GoodsQRCodeInfoForm goodsQRCodeInfoForm = new GoodsQRCodeInfoForm();
        goodsQRCodeInfoForm.setGuid(guid);
        BaseInfoDO baseInfoDO = this.initiSaveObject();
        if(baseInfoDO==null){return responseError(new ResultVO(ResultEnum.TOKEN_EXPIRED));}
        BeanCopyUtil.copyBean(baseInfoDO,goodsQRCodeInfoForm);
        ResultVO resultVO = goodsQRCodeManagerService.delGoodsQRCodeById(goodsQRCodeInfoForm);
        return responseSuccess(resultVO);
    }

    @ApiOperation(value = "预览溯源码信息",notes = "通过溯源码加密字符，查询溯源码信息")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "qrToken",value = "溯源码加密字符",dataType = "String",paramType = "query")
    })
    @ApiResponse(code =0,message = "操作成功")
    @AuthOrgValidate
    @GetMapping("/show")
    public ResponseBase getQRCodeInfo(@RequestParam("qrToken") String qrToken){
        ResultVO resultVO = goodsQRCodeManagerService.getGoodsQRCodeDetailInfoByToken(qrToken);
        return responseSuccess(resultVO);
    }

    @ApiOperation(value = "溯源码打印",notes = "溯源码打印")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "goodsQRCodeInfoForm",value = "查询条件",dataType = "GoodsQRCodeInfoForm")
    })
    @ApiResponse(code =0,message = "查询成功")
    @AuthOrgValidate(value = OrgAuthEnum.PLATFORM_GOODS_CODE_PRINT)
    @ResponseBody
    @PostMapping("/getPrintDetail")
    public ResponseBase printDetail(@RequestBody GoodsQRCodeInfoForm goodsQRCodeInfoForm){
        ResultVO tempVo = goodsQRCodeManagerService.getPrintDetail(goodsQRCodeInfoForm);
        return responseSuccess(tempVo);
    }
    
    @ApiOperation(value = "修改溯源码打印状态",notes = "修改溯源码打印状态")
    @ApiImplicitParams({
    	@ApiImplicitParam(name = "ids",value = "打印溯源码id",dataType = "String")
    })
    @ApiResponse(code =0,message = "操作成功")
    @AuthOrgValidate(value = OrgAuthEnum.PLATFORM_GOODS_CODE_PRINT)
    @ResponseBody
    @PostMapping("/updateQRIsPrint")
    public ResponseBase updateQRIsPrint(@RequestBody List<String> ids){
    	if(null == ids || ids.size() < 1) {
    		throw new GlobalException(1, "没有要修改的溯源码打印状态");
    	}
    	ResultVO tempVo = goodsQRCodeManagerService.updateQRIsPrint(ids);
    	return responseSuccess(tempVo);
    }
}
