package com.hcloud.microservice.traced.web.goodsmanager;

import com.alibaba.fastjson.JSONObject;
import com.hcloud.microserver.commoncore.annotation.AuthOrgValidate;
import com.hcloud.microserver.commoncore.base.ResponseBase;
import com.hcloud.microserver.commoncore.base.ResultVO;
import com.hcloud.microserver.commoncore.enums.OrgAuthEnum;
import com.hcloud.microserver.commoncore.enums.ResultEnum;
import com.hcloud.microserver.commoncore.util.BeanCopyUtil;
import com.hcloud.microserver.commoncore.util.DateUtils;
import com.hcloud.microserver.commoncore.util.ExportExcelUtil;
import com.hcloud.microserver.commoncore.util.export.DataField;
import com.hcloud.microservice.goods.facade.clients.GoodsQRCodeRecordManagerService;
import com.hcloud.microservice.goods.facade.forms.GoodsQRCodeRecordForm;
import com.hcloud.microservice.goods.facade.forms.GoodsQRCodeRecordStatForm;
import com.hcloud.microservice.traced.common.BaseInfoDO;
import com.hcloud.microservice.traced.common.TracedBaseController;
import io.swagger.annotations.*;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.*;

import java.util.Date;
import java.util.List;
import java.util.Map;

/**
 * @author xiezt
 */
@Controller
@RequestMapping("/web/code/record")
@Api(description = "二维码生成记录服务")
public class QRCodeRecordManageController extends TracedBaseController {

    @Value("${export.file.excel.path}")
    private String filePath;

    @Autowired
    private GoodsQRCodeRecordManagerService goodsQRCodeRecordManagerService;

    @ApiOperation(value = "查询溯源码生成记录信息",notes = "分页查询溯源码生成记录信息，默认分页条数10条")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "goodsQRCodeRecordForm",value = "查询条件",dataType = "GoodsQRCodeRecordForm")
    })
    @ApiResponse(code =0,message = "查询成功")
    @AuthOrgValidate(value = OrgAuthEnum.PLATFORM_GOODS_CODE_QUERY)
    @ResponseBody
    @PostMapping("/searchByPage")
    public ResponseBase searchByPage(@RequestBody GoodsQRCodeRecordForm goodsQRCodeRecordForm){
        goodsQRCodeRecordForm.setFkOrgGuid(this.getOrgGuid());
        ResultVO resultVO = goodsQRCodeRecordManagerService.searchGoodsQRCodeRecordByPage(goodsQRCodeRecordForm);
        return responseSuccess(resultVO);
    }

    @ApiOperation(value = "预览溯源码信息",notes = "通过生成记录Id查询溯源码预览信息")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "guid",value = "查询条件",dataType = "String",paramType = "query")
    })
    @ApiResponse(code =0,message = "查询成功")
    @AuthOrgValidate(value = OrgAuthEnum.PLATFORM_GOODS_CODE_GET)
    @ResponseBody
    @GetMapping("/showDetail")
    public ResponseBase getDetailByParentId(@RequestParam("guid") String recordId){
        GoodsQRCodeRecordForm recordForm = new GoodsQRCodeRecordForm();
        recordForm.setGuid(recordId);
        recordForm.setPageNo(1);
        recordForm.setPageSize(18);
        ResultVO tempVo = goodsQRCodeRecordManagerService.getGoodsQRCodeInfoByRecordId(recordForm);
        List<Map> tmpList = (List<Map>) tempVo.getData();
        if(null!=tmpList && tmpList.size()>0){
            Map map = tmpList.get(0);
            String parentCode = (String) map.get("qrcodeParentCode");
            String image = (String) map.get("qrcodeImg");
            map.put("imagesPath","images/"+parentCode+"/"+image);  //为什么在这里这样拼接，因为前端不想拼接，ps和善的微笑
            ResultVO resultVO = new ResultVO(ResultEnum.SUCCESS,map);
            return responseSuccess(resultVO);
        }else {
            return responseError(new ResultVO(ResultEnum.SYS_ERROR));
        }
    }

    @ApiOperation(value = "查询溯源码生成记录明细",notes = "查询溯源码生成记录明细")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "recordForm",value = "查询条件",dataType = "GoodsQRCodeRecordForm")
    })
    @ApiResponse(code =0,message = "查询成功")
    @AuthOrgValidate(value = OrgAuthEnum.PLATFORM_GOODS_CODE_DETAIL)
    @ResponseBody
    @PostMapping("/searchDetailById")
    public ResponseBase searchDetailByParentId(@RequestBody GoodsQRCodeRecordForm recordForm){
        ResultVO resultVO = goodsQRCodeRecordManagerService.getGoodsQRCodeInfoByRecordId(recordForm);
        return responseSuccess(resultVO);
    }


    @ApiOperation(value = "导出溯源码生成记录",notes = "导出溯源码生成记录")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "guid",value = "溯源码生成记录唯一标识",dataType = "String",paramType = "query")
    })
    @AuthOrgValidate(value = OrgAuthEnum.PLATFORM_GOODS_CODE_EXPORT)
    @GetMapping("/exportDetailRecord")
    public void searchDetailForExport(@RequestParam("guid") String recordId){
        GoodsQRCodeRecordForm recordForm = new GoodsQRCodeRecordForm();
        recordForm.setPageSize(1000000);
        recordForm.setGuid(recordId);
        ResultVO resultVO = goodsQRCodeRecordManagerService.searchGoodsQRCodeRecordForExport(recordForm);
        List<Map<String,String>> resultList = (List<Map<String, String>>) resultVO.getData();
            DataField[] fields = {new DataField("商品名称", "goodsName", 10),
                    new DataField("溯源码", "qrcode", 30),
                    new DataField("溯源加密码", "qrcodeToken", 30),
                    new DataField("溯源码地址", "qrcodeUrl", 20),
                    new DataField("扫码次数", "scanCount", 20),
                    new DataField("首次扫码时间", "scanFirstTimed", 20),
                    new DataField("最后一次扫码时间", "scanLastTimed", 20)
            };
       ExportExcelUtil.exportExcelForBoot(this.getResponseObject(), resultList, fields, "溯源码列表信息-" + DateUtils.getShortYMDHMS(),filePath);
    }

    @ApiOperation(value = "废除溯源码生成记录",notes = "废除溯源码生成记录（含溯源码明细）")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "guid",value = "生成记录唯一主键",dataType = "String",paramType = "query")
    })
    @ApiResponse(code =0,message = "操作成功")
    @AuthOrgValidate(value = OrgAuthEnum.PLATFORM_GOODS_CODE_ABOLISH)
    @ResponseBody
    @GetMapping("/forbiddenCodeInfo")
    public ResponseBase abolishCodeInfo(@RequestParam("guid") String recordId){
        GoodsQRCodeRecordForm recordForm = new GoodsQRCodeRecordForm();
        recordForm.setGuid(recordId);
        BaseInfoDO baseInfoDO = this.initiSaveObject();
        BeanCopyUtil.copyBean(baseInfoDO,recordForm);
        ResultVO resultVO = goodsQRCodeRecordManagerService.delGoodsQRCodeRecord(recordForm);
        return responseSuccess(resultVO);
    }


    @ApiOperation(value = "删除溯源码生成记录",notes = "删除溯源码生成记录(含溯源码明细)")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "guid",value = "生成记录唯一主键",dataType = "String",paramType = "query")
    })
    @ApiResponse(code =0,message = "操作成功")
    @AuthOrgValidate(value = OrgAuthEnum.PLATFORM_GOODS_CODE_DEL)
    @ResponseBody
    @GetMapping("/delByPhysical")
    public ResponseBase delCodeRecordByPhysical(@RequestParam("guid") String recordId){
        ResultVO resultVO = goodsQRCodeRecordManagerService.delQRCodeInfoPhysical(recordId);
        return responseSuccess(resultVO);
    }

    @ApiOperation(value = "统计一年各月扫码人数", notes = "统计结果为12个月每个月的扫码人数")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "year", value = "年", dataType = "Integer", paramType = "query")
    })
    @AuthOrgValidate//(value = OrgAuthEnum.PLATFORM_GOODS_CODE_STAT_ONE_YEAR_SCAN_NUMS)
    @ResponseBody
    @PostMapping("/statOneYear")
    public ResponseBase statOneYearScanNumber(@RequestBody GoodsQRCodeRecordStatForm goodsQRCodeRecordStatForm) {
        // 统计当前用户所属机构的数据,所以加入机构guid
        goodsQRCodeRecordStatForm.setFkOrgGuid(this.getOrgGuid());
        if(goodsQRCodeRecordStatForm.getYear() == null) {
        	goodsQRCodeRecordStatForm.setYear(DateUtils.getYear(new Date()));
        }
        ResultVO resultVO = this.goodsQRCodeRecordManagerService.statOneYearScanNumber(goodsQRCodeRecordStatForm);
        return responseSuccess(resultVO);
    }

    @ApiOperation(value = "统计当天和历史累计扫码人数", notes = "暂时先这么弄")
    @AuthOrgValidate//(value = OrgAuthEnum.PLATFORM_GOODS_CODE_STAT_YESTERDAY_AND_ALL_TIME_SCAN_NUMS)
    @ResponseBody
    @PostMapping("/statYesterdayAndAllTime")
    public ResponseBase statYesterdayAndAllTimeScanNumber(@RequestBody GoodsQRCodeRecordStatForm goodsQRCodeRecordStatForm) {
        goodsQRCodeRecordStatForm.setFkOrgGuid(this.getOrgGuid());
        ResultVO resultVO = this.goodsQRCodeRecordManagerService.statYesterdayAndAllTimeScanNumber(goodsQRCodeRecordStatForm);
        return responseSuccess(resultVO);
    }

    @ApiOperation(value = "统计当天各小时扫码人数", notes = "暂时先这么弄")
    @AuthOrgValidate(value = OrgAuthEnum.PLATFORM_GOODS_CODE_STAT_ONE_DAY_SCAN_NUMS)
    @ResponseBody
    @PostMapping("/statOneDayAllHours")
    public ResponseBase statOneDayAllHoursScanNumber(@RequestBody GoodsQRCodeRecordStatForm goodsQRCodeRecordStatForm) {
        goodsQRCodeRecordStatForm.setFkOrgGuid(this.getOrgGuid());
        ResultVO resultVO = this.goodsQRCodeRecordManagerService.statOneDayAllHoursScanNumber(goodsQRCodeRecordStatForm);
        return responseSuccess(resultVO);
    }

    @ApiOperation(value = "统计一周7天每天的扫码人数")
    @AuthOrgValidate(value = OrgAuthEnum.PLATFORM_GOODS_CODE_STAT_ONE_WEEK_SCAN_NUMS)
    @ResponseBody
    @PostMapping("/statOneWeekSevenDay")
    public ResponseBase statOneWeekSevenDayScanNumber(@RequestBody GoodsQRCodeRecordStatForm goodsQRCodeRecordStatForm) {
        goodsQRCodeRecordStatForm.setFkOrgGuid(this.getOrgGuid());
        ResultVO resultVO = this.goodsQRCodeRecordManagerService.statOneWeekSevenDayScanNumber(goodsQRCodeRecordStatForm);
        return responseSuccess(resultVO);
    }

    @ApiOperation(value = "统计本月每天的扫码人数")
    @AuthOrgValidate(value = OrgAuthEnum.PLATFORM_GOODS_CODE_STAT_ONE_MONTH_SCAN_NUMS)
    @ResponseBody
    @PostMapping("/statOneMonthAllDays")
    public ResponseBase statOneMonthAllDaysScanNumber(@RequestBody GoodsQRCodeRecordStatForm goodsQRCodeRecordStatForm) {
        goodsQRCodeRecordStatForm.setFkOrgGuid(this.getOrgGuid());
        ResultVO resultVO = this.goodsQRCodeRecordManagerService.statOneMonthAllDaysScanNumber(goodsQRCodeRecordStatForm);
        return responseSuccess(resultVO);
    }
}