package com.hcloud.microservice.traced.web.sysmanager;


import com.google.common.collect.Lists;
import com.hcloud.microserver.commoncore.annotation.AuthOrgValidate;
import com.hcloud.microserver.commoncore.annotation.AuthValidate;
import com.hcloud.microserver.commoncore.base.BaseController;
import com.hcloud.microserver.commoncore.base.ResponseBase;
import com.hcloud.microserver.commoncore.base.ResultVO;
import com.hcloud.microserver.commoncore.enums.AuthEnum;
import com.hcloud.microserver.commoncore.enums.OrgAuthEnum;
import com.hcloud.microserver.commoncore.util.BeanCopyUtil;
import com.hcloud.microservice.org.facade.client.AuthManagerService;
import com.hcloud.microservice.org.facade.forms.BaseAuthForm;
import com.hcloud.microservice.org.facade.forms.BaseRoleAuthForm;
import com.hcloud.microservice.org.facade.forms.BaseUserAuthForm;
import com.hcloud.microservice.traced.common.TracedBaseController;
import io.swagger.annotations.*;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.List;
@Slf4j
@RestController
@RequestMapping("/web/auth")
@Api(description = "平台菜单服务")
public class AuthManagerController extends TracedBaseController {

    @Autowired
    private AuthManagerService authManagerService;


    @ApiOperation(value = "查询平台权限",notes = "根据平台权限信息查询平台权限记录")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "baseAuthForm",value = "查询条件",dataType = "BaseAuthForm")
    })
    @ApiResponse(code =0,message = "查询成功")
    @AuthOrgValidate(value = OrgAuthEnum.PLATFORM_AUTH_QUERY)
    @PostMapping("/searchByPage")
    public ResponseBase searchAuthByPage(@RequestBody BaseAuthForm baseAuthForm){
        ResultVO resultVO = authManagerService.searchAuthInfoByPage(baseAuthForm);
        return responseSuccess(resultVO);
    }

    @ApiOperation(value = "添加平台权限信息",notes = "根据平台权限信息添加平台记录")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "baseAuthForm",value = "权限信息",dataType = "BaseAuthForm")
    })
    @ApiResponse(code =0,message = "添加成功")
    @AuthOrgValidate(value = OrgAuthEnum.PLATFORM_AUTH_ADD)
    @PostMapping("/add")
    public ResponseBase addAuthInfo(@RequestBody BaseAuthForm baseAuthForm){
        ResultVO resultVO = authManagerService.addAuthInfo(baseAuthForm);
        if(resultVO.getCode()==0){
            return responseSuccess(resultVO);
        }
        return responseError(resultVO);
    }

    @ApiOperation(value = "修改平台权限信息",notes = "根据平台权限信息修改平台记录")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "baseAuthForm",value = "权限信息",dataType = "BaseAuthForm")
    })
    @ApiResponse(code =0,message = "修改成功")
    @AuthOrgValidate(value = OrgAuthEnum.PLATFORM_AUTH_EDIT)
    @PostMapping("/edit")
    public ResponseBase editAuthInfo(@RequestBody BaseAuthForm baseAuthForm){
        ResultVO resultVO = authManagerService.updateAuthInfo(baseAuthForm);
        if(resultVO.getCode()==0){
            return responseSuccess(resultVO);
        }
        return responseError(resultVO);
    }

    @ApiOperation(value = "删除平台权限信息",notes = "根据平台权限信息删除平台记录")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "guid",value = "权限主键",paramType = "query",dataType = "String")
    })
    @ApiResponse(code =0,message = "删除成功")
    @AuthOrgValidate(value = OrgAuthEnum.PLATFORM_AUTH_DELETE)
    @GetMapping("/del")
    public ResponseBase delAuthInfo(@RequestParam("authId") String guid){
        BaseAuthForm baseAuthForm = new BaseAuthForm();
        baseAuthForm.setState(0);
        baseAuthForm.setGuid(guid);
        ResultVO resultVO = authManagerService.updateAuthInfo(baseAuthForm);
        if(resultVO.getCode()==0){
            return responseSuccess(resultVO);
        }
        return responseError(resultVO);
    }

    @ApiOperation(value = "禁用平台权限信息",notes = "根据平台权限信息禁用平台记录")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "guid",value = "权限主键",paramType = "query",dataType = "String")
    })
    @ApiResponse(code =0,message = "操作成功")
    @AuthOrgValidate(value = OrgAuthEnum.PLATFORM_AUTH_FORBIDDEN)
    @GetMapping("/forbidden")
    public ResponseBase forbiddenAuthInfo(@RequestParam("authId") String guid){
        BaseAuthForm baseAuthForm = new BaseAuthForm();
        baseAuthForm.setIsForbid(1);
        baseAuthForm.setGuid(guid);
        ResultVO resultVO = authManagerService.updateAuthInfo(baseAuthForm);
        if(resultVO.getCode()==0){
            return responseSuccess(resultVO);
        }
        return responseError(resultVO);
    }
}