package com.hcloud.microservice.traced.web.sysmanager;

import com.hcloud.microserver.commoncore.annotation.AuthOrgValidate;
import com.hcloud.microserver.commoncore.annotation.AuthValidate;
import com.hcloud.microserver.commoncore.base.BaseController;
import com.hcloud.microserver.commoncore.base.ResponseBase;
import com.hcloud.microserver.commoncore.base.ResultVO;
import com.hcloud.microserver.commoncore.constant.GlobleConstant;
import com.hcloud.microserver.commoncore.enums.OrgAuthEnum;
import com.hcloud.microservice.org.facade.client.RoleManagerService;
import com.hcloud.microservice.org.facade.forms.BaseRoleForm;
import com.hcloud.microservice.traced.common.TracedBaseController;
import io.swagger.annotations.*;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.Date;

/**
 * @author xiezt
 */
@Slf4j
@RestController
@RequestMapping("/web/role")
@Api(description = "角色管理服务")
public class RoleManagerController extends TracedBaseController {

    @Autowired
    private RoleManagerService roleManagerService;

    @ApiOperation(value = "分页查询角色信息",notes = "返回值里的count是记录的总数，")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "baseRoleForm",value = "角色查询信息",dataType = "BaseRoleForm")
    })
    @ApiResponse(code =600,message = "操作成功")
    @AuthOrgValidate(value = OrgAuthEnum.PLATFORM_ROLE_QUERY)
    @PostMapping("/searchByPage")
    public ResponseBase searchRoleInfoByPage(@RequestBody BaseRoleForm baseRoleForm){
        baseRoleForm.setFkOrgGuid(this.getOrgGuid());
        ResultVO resultVO = roleManagerService.searchRoleInfoByPage(baseRoleForm);
        return responseSuccess(resultVO);
    }

    @ApiOperation(value = "添加角色信息",notes = "根据角色信息添加角色记录，")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "baseRoleForm",value = "角色信息对象",dataType = "BaseRoleForm")
    })
    @ApiResponse(code =0,message = "操作成功")
    @AuthOrgValidate(value = OrgAuthEnum.PLATFORM_ROLE_ADD)
    @PostMapping("/add")
    public ResponseBase addRoleInfo(@RequestBody BaseRoleForm baseRoleForm){
        baseRoleForm.setFkOrgGuid(this.getOrgGuid());
        baseRoleForm.setFkProductGuid(GlobleConstant.PRODUCT_GUID);
        baseRoleForm.setState(1);
        baseRoleForm.setCreateUser(this.getUserId());
        baseRoleForm.setModifiedUser(this.getUserId());
        baseRoleForm.setCreateTime(new Date());
        baseRoleForm.setModifiedTime(new Date());
        ResultVO resultVO = roleManagerService.addRoleInfo(baseRoleForm);
        if (null!= resultVO && resultVO.getCode() == 0) {
            return responseSuccess(resultVO);
        }
        return responseError(resultVO);
    }

    @ApiOperation(value = "修改角色信息",notes = "根据角色信息修改角色记录，")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "baseRoleForm",value = "角色信息对象",dataType = "BaseRoleForm")
    })
    @ApiResponse(code =0,message = "操作成功")
    @AuthOrgValidate(value = OrgAuthEnum.PLATFORM_ROLE_EDIT)
    @PostMapping("/edit")
    public ResponseBase editRoleInfo(@RequestBody BaseRoleForm baseRoleForm){
        ResultVO resultVO = roleManagerService.updateRoleInfo(baseRoleForm);
        if (null!= resultVO && resultVO.getCode() == 0) {
            return responseSuccess(resultVO);
        }
        return responseError(resultVO);
    }


    @ApiOperation(value = "查询角色明细信息",notes = "根据角色id修改角色记录")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "guid",value = "角色Id",paramType = "query",dataType = "String")
    })
    @ApiResponse(code =0,message = "操作成功")
    @AuthOrgValidate(value = OrgAuthEnum.PLATFORM_ROLE_GET)
    @GetMapping("/searchById")
    public ResponseBase searchInfoById(@RequestParam("guid") String guid){
        ResultVO resultVO = roleManagerService.searchInfoById(guid);
        if (null!= resultVO && resultVO.getCode() == 0) {
            return responseSuccess(resultVO);
        }
        return responseError(resultVO);
    }

    @ApiOperation(value = "删除角色信息",notes = "根据角色信息修改角色记录，")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "baseRoleForm",value = "角色信息对象",paramType = "query",dataType = "BaseRoleForm")
    })
    @ApiResponse(code =0,message = "操作成功")
    @AuthOrgValidate(value = OrgAuthEnum.PLATFORM_ROLE_DEL)
    @GetMapping("/del")
    public ResponseBase delRoleInfo(@RequestParam("guid") String roleId){
        BaseRoleForm baseRoleForm  = new BaseRoleForm();
        baseRoleForm.setGuid(roleId);
        baseRoleForm.setState(0);
        ResultVO resultVO = roleManagerService.updateRoleInfo(baseRoleForm);
        if (null!= resultVO && resultVO.getCode() == 0) {
            return responseSuccess(resultVO);
        }
        return responseError(resultVO);
    }

    @ApiOperation(value = "查询角色权限信息",notes = "只能查询本机构下的权限信息，")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "roleId",value = "角色ID",paramType = "query",dataType = "String")
    })
    @ApiResponse(code =0,message = "操作成功")
    @AuthOrgValidate(value = OrgAuthEnum.PLATFORM_ROLE_SEARCH_AUTH)
    @GetMapping("/searchRoleAuthInfo")
    public ResponseBase searchRoleAuthInfo(@RequestParam("roleId") String roleId){
        log.info("orgGuid===============>{}",this.getOrgGuid());
        ResultVO resultVO = roleManagerService.searchRoleAuthInfo(roleId,this.getOrgGuid());
        if (null!= resultVO && resultVO.getCode() == 0) {
            return responseSuccess(resultVO);
        }
        return responseError(resultVO);
    }

    @ApiOperation(value = "分配角色权限信息",notes = "只能分配本机构下的权限信息，")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "baseRoleForm",value = "角色信息对象",dataType = "BaseRoleForm")
    })
    @ApiResponse(code =0,message = "操作成功")
    @AuthOrgValidate(value = OrgAuthEnum.PLATFORM_ROLE_DIS_AUTH)
    @PostMapping("/distrRoleAuthInfo")
    public ResponseBase distrRoleAuthInfo(@RequestBody BaseRoleForm baseRoleForm){
        ResultVO resultVO = roleManagerService.distributionRoleAuth(baseRoleForm.getGuid(),this.getOrgGuid(),baseRoleForm.getMenuList());
        if (null!= resultVO && resultVO.getCode() == 0) {
            return responseSuccess(resultVO);
        }
        return responseError(resultVO);
    }
}