package com.hcloud.microservice.traced.web.sysmanager;

import com.hcloud.microserver.commoncore.annotation.AuthOrgValidate;
import com.hcloud.microserver.commoncore.annotation.AuthValidate;
import com.hcloud.microserver.commoncore.base.BaseController;
import com.hcloud.microserver.commoncore.base.ResponseBase;
import com.hcloud.microserver.commoncore.base.ResultVO;
import com.hcloud.microserver.commoncore.constant.GlobleConstant;
import com.hcloud.microserver.commoncore.enums.AuthEnum;
import com.hcloud.microserver.commoncore.enums.OrgAuthEnum;
import com.hcloud.microserver.commoncore.enums.ResultEnum;
import com.hcloud.microserver.commoncore.util.BeanCopyUtil;
import com.hcloud.microserver.commoncore.util.Md5Util;
import com.hcloud.microservice.org.facade.client.UserManagerService;
import com.hcloud.microservice.org.facade.forms.BaseUserForm;
import com.hcloud.microservice.traced.common.BaseInfoDO;
import com.hcloud.microservice.traced.common.TracedBaseController;
import io.swagger.annotations.*;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.redis.core.RedisTemplate;
import org.springframework.web.bind.annotation.*;

import java.util.List;

/**
 * @author xiezt
 */
@Slf4j
@RestController
@RequestMapping("/web/user")
@Api(description = "用户管理服务")
public class UserManagerController extends TracedBaseController {

    private static final String INIT_PWD="123123";

    @Autowired
    private UserManagerService userManagerService;

    @Autowired
    private RedisTemplate redisTemplate;


    @ApiOperation(value = "用户登录",notes = "根据用户名及密码完成登录动作，")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "baseUserForm",value = "用户登录信息（账号，密码）",dataType = "BaseUserForm")
    })
    @ApiResponse(code =600,message = "账号或密码不正确")
    @AuthOrgValidate
    @PostMapping("/login")
    public ResponseBase login(@RequestBody BaseUserForm baseUserForm){
        log.info("account====================>{}",baseUserForm.getAccount());
        log.info("password====================>{}",baseUserForm.getPasswd());
        ResultVO resultVO = userManagerService.loginSystem(baseUserForm.getAccount(),baseUserForm.getPasswd());
        if(resultVO.getCode()==0){
            return responseSuccess(resultVO);
        }
        return responseError(resultVO);
    }


    @ApiOperation(value = "用户登出",notes = "根据用户名访问token注销登录用户，")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "accessToken",value = "权限token",dataType = "String")
    })
    @ApiResponse(code =600,message = "账号或密码不正确")
    @AuthOrgValidate
    @GetMapping("/logout")
    public ResponseBase logout(){
        redisTemplate.delete(this.getRequestObject().getHeader(ACCESS_TOKEN));
        ResultVO resultVO = new ResultVO(ResultEnum.SUCCESS);
        return responseSuccess(resultVO);
    }

    @ApiOperation(value = "添加用户信息",notes = "根据用户信息添加用户记录")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "baseUserForm",value = "用户信息",dataType = "BaseUserForm")
    })
    @ApiResponse(code =609,message = "账号重复")
    @AuthOrgValidate(value = OrgAuthEnum.PLATFORM_USER_ADD)
    @PostMapping("/add")
    public ResponseBase addUserInfo(@RequestBody BaseUserForm baseUserForm){
        BaseInfoDO infoDO = this.initiSaveObject();
        if(infoDO==null){return responseError(new ResultVO(ResultEnum.TOKEN_EXPIRED));}
        String remark = baseUserForm.getRemark();
        BeanCopyUtil.copyBean(infoDO,baseUserForm);
        baseUserForm.setRemark(remark);
        ResultVO resultVO = userManagerService.addUserInfo(baseUserForm);
        if(null!= resultVO && resultVO.getCode()==0){
            return responseSuccess(resultVO);
        }
        return responseError(resultVO);
    }

    @ApiOperation(value = "修改用户信息",notes = "根据用户信息修改用户记录")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "baseUserForm",value = "用户信息",dataType = "BaseUserForm")
    })
    @ApiResponse(code =0,message = "操作成功")
    @AuthOrgValidate(value = OrgAuthEnum.PLATFORM_USER_EDIT)
    @PostMapping("/edit")
    public ResponseBase editUserInfo(@RequestBody BaseUserForm baseUserForm){
        ResultVO resultVO = userManagerService.updateUserInfo(baseUserForm);
        if(null!= resultVO && resultVO.getCode()==0){
            return responseSuccess(resultVO);
        }
        return responseError(resultVO);
    }

    @ApiOperation(value = "禁用用户信息",notes = "根据用户信息修改用户记录")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "guid",value = "用户id",paramType = "query",dataType = "String")
    })
    @ApiResponse(code =0,message = "操作成功")
    @AuthOrgValidate(value = OrgAuthEnum.PLATFORM_USER_FORBIDDEN)
    @GetMapping("/forbidden")
    public ResponseBase forbiddenUserInfo(@RequestParam("guid") String guid,@RequestParam("isForbid") Integer isForbid){
        log.info("==================>{}",this.getOrgGuid());
        BaseUserForm baseUserForm = new BaseUserForm();
        baseUserForm.setGuid(guid);
        baseUserForm.setFkOrgGuid(this.getOrgGuid());
        if(isForbid==0){
            baseUserForm.setIsForbid(1);
        }else{
            baseUserForm.setIsForbid(0);
        }
        ResultVO resultVO = userManagerService.updateUserInfo(baseUserForm);
        if(null!= resultVO && resultVO.getCode()==0){
            return responseSuccess(resultVO);
        }
        return responseError(resultVO);
    }

    @ApiOperation(value = "删除用户信息",notes = "根据用户唯一标记用户记录")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "guid",value = "用户id",paramType = "query",dataType = "String")
    })
    @ApiResponse(code =0,message = "操作成功")
    @AuthOrgValidate(value = OrgAuthEnum.PLATFORM_USER_DEL)
    @GetMapping("/del")
    public ResponseBase delUserInfo(@RequestParam("guid") String guid){
        log.info("==================>{}",this.getOrgGuid());
        BaseUserForm baseUserForm = new BaseUserForm();
        baseUserForm.setGuid(guid);
        baseUserForm.setFkOrgGuid(this.getOrgGuid());
        baseUserForm.setState(0);
        ResultVO resultVO = userManagerService.updateUserInfo(baseUserForm);
        if(null!= resultVO && resultVO.getCode()==0){
            return responseSuccess(resultVO);
        }
        return responseError(resultVO);
    }

    @ApiOperation(value = "重置用户密码",notes = "初始化用户密码")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "guid",value = "用户id",paramType = "query",dataType = "String")
    })
    @ApiResponse(code =0,message = "操作成功")
    @AuthOrgValidate(value = OrgAuthEnum.PLATFORM_USER_EDIT)
    @GetMapping("/restPwd")
    public ResponseBase restUserPwd(@RequestParam("guid") String guid){
        log.info("==================>{}",this.getOrgGuid());
        BaseUserForm baseUserForm = new BaseUserForm();
        baseUserForm.setGuid(guid);
        baseUserForm.setFkOrgGuid(this.getOrgGuid());
        baseUserForm.setPasswd(INIT_PWD);
        ResultVO resultVO = userManagerService.updateUserInfo(baseUserForm);
        if(null!= resultVO && resultVO.getCode()==0){
            return responseSuccess(resultVO);
        }
        return responseError(resultVO);
    }

    @ApiOperation(value = "查询用户权限信息",notes = "与机构权限整合的权限信息")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "guid",value = "用户Id",paramType = "query",dataType = "String")
    })
    @ApiResponse(code =0,message = "操作成功")
    @AuthOrgValidate(value = OrgAuthEnum.PLATFORM_USER_SEARCH_AUTH)
    @GetMapping("/searchUserAuthInfo")
    public ResponseBase searchUserAuthInfo(@RequestParam("guid") String guid){
        ResultVO resultVO = userManagerService.searchUserAuthInfo(guid,this.getOrgGuid());
        if(null!= resultVO && resultVO.getCode()==0){
            return responseSuccess(resultVO);
        }
        return responseError(resultVO);
    }

    @ApiOperation(value = "查询用户信息",notes = "分页查询用户信息")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "baseUserForm",value = "用户对象",dataType = "BaseUserForm")
    })
    @ApiResponse(code =0,message = "操作成功")
    @AuthOrgValidate(value = OrgAuthEnum.PLATFORM_USER_QUERY)
    @PostMapping("/searchByPage")
    public ResponseBase searchUserInfo(@RequestBody BaseUserForm baseUserForm){
        if(this.getOrgGuid()==null){
            return responseError(new ResultVO(ResultEnum.TOKEN_EXPIRED));
        }
        baseUserForm.setFkOrgGuid(this.getOrgGuid());
        ResultVO resultVO = userManagerService.searchUserInfoByPage(baseUserForm);
        if(null!= resultVO && resultVO.getCode()==0){
            return responseSuccess(resultVO);
        }
        return responseError(resultVO);
    }

    @ApiOperation(value = "查询用户明细信息",notes = "用户明细")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "guid",value = "用户ID",paramType = "query",dataType = "String")
    })
    @ApiResponse(code =0,message = "操作成功")
    @AuthOrgValidate(value = OrgAuthEnum.PLATFORM_USER_GET)
    @GetMapping("/searchById")
    public ResponseBase searchUserInfoById(@RequestParam("guid") String guid){
        BaseUserForm baseUserForm = new BaseUserForm();
        baseUserForm.setGuid(guid);
        baseUserForm.setFkOrgGuid(this.getOrgGuid());
        ResultVO resultVO = userManagerService.searchUserInfoByPage(baseUserForm);
        if(null!= resultVO && resultVO.getCode()==0){
            List list = (List) resultVO.getData();
            if(null!=list && list.size()>0){
                return responseSuccess(success(list.get(0)));
            }
        }
        return responseError(resultVO);
    }
}
